local dt = require "darktable"
local du = require "lib/dtutils"

local MODULE = "EXIFtime_from_fname"

local pattern = {
  "IMG%-(%d%d%d%d)(%d%d)(%d%d)",
  "CameraZOOM%-(%d%d%d%d)(%d%d)(%d%d)(%d%d)(%d%d)(%d%d)",
  "(%d%d%d%d)(%d%d)(%d%d)_(%d%d)(%d%d)(%d%d)",
  "(%d%d%d%d)%-(%d%d)%-(%d%d) (%d%d)%.(%d%d)%.(%d%d)"
}

local function set_image_time(images)
  for _, img in ipairs(images) do
    dt.print_log("processing " .. img.filename)
    local valid, y, m, d, h, mi, s, pat = nil
    if string.match(img.filename, "^IMG") then
      y, m, d = string.match(img.filename, pattern[1])
      h, mi, s = 0, 0, 0
      valid = 1
    else
      if string.match(img.filename, "^CameraZOOM") then
        pat = pattern[2]
        valid = 1
      elseif string.match(img.filename, "_") then
        pat = pattern[3]
        valid = 1
      elseif string.match(img.filename, "^%d%d%d%d%-%d") then
        pat = pattern[4]
        valid = 1
      end
      y, m, d, h, mi, s = string.match(img.filename, pat)
    end
    if valid then
      local exif_time = string.format("%4d:%02d:%02d %02d:%02d:%02d", y, m, d, h, mi, s)
      dt.print_log("would set image time to " .. exif_time)
      img.exif_datetime_taken = exif_time
    end
  end
end


dt.register_event(MODULE .. "_collection", "shortcut",
  function(event, shortcut)
    -- ignore the film roll, it contains all the images, not just the imported
    local images = dt.collection
    set_image_time(images)
  end,
  "Set image exiftime for collection"
)

dt.register_event(MODULE .. "_selection", "shortcut",
  function(event, shortcut)
    local images = dt.gui.selection()
    set_image_time(images)
  end,
  "Set image exiftime for selection"
)

